==> openshift-model-operator-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ClusterNetworkEntryFluentImpl<A extends ClusterNetworkEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterNetworkEntryFluent<A> {

    private String cidr;
    private Integer hostPrefix;

    public ClusterNetworkEntryFluentImpl() {
    }

    public ClusterNetworkEntryFluentImpl(ClusterNetworkEntry instance) {
        this.withCidr(instance.getCidr()); 
        this.withHostPrefix(instance.getHostPrefix()); 
    }

    public String getCidr() {
        return this.cidr;
    }

    public A withCidr(String cidr) {
        this.cidr=cidr; return (A) this;
    }

    public Boolean hasCidr() {
        return this.cidr != null;
    }

    public A withNewCidr(String arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(StringBuilder arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(StringBuffer arg1) {
        return (A)withCidr(new String(arg1));
    }

    public Integer getHostPrefix() {
        return this.hostPrefix;
    }

    public A withHostPrefix(Integer hostPrefix) {
        this.hostPrefix=hostPrefix; return (A) this;
    }

    public Boolean hasHostPrefix() {
        return this.hostPrefix != null;
    }

    public A withNewHostPrefix(String arg1) {
        return (A)withHostPrefix(new Integer(arg1));
    }

    public A withNewHostPrefix(int arg1) {
        return (A)withHostPrefix(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
        if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
        if (hostPrefix != null ? !hostPrefix.equals(that.hostPrefix) :that.hostPrefix != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(cidr,  hostPrefix,  super.hashCode());
    }

}

==> openshift-model-operator-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ClusterNetworkEntryFluentImpl<A extends ClusterNetworkEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterNetworkEntryFluent<A> {

    private String cidr;
    private Integer hostPrefix;

    public ClusterNetworkEntryFluentImpl() {
    }

    public ClusterNetworkEntryFluentImpl(ClusterNetworkEntry instance) {
        this.withCidr(instance.getCidr()); 
        this.withHostPrefix(instance.getHostPrefix()); 
    }

    public String getCidr() {
        return this.cidr;
    }

    public A withCidr(String cidr) {
        this.cidr=cidr; return (A) this;
    }

    public Boolean hasCidr() {
        return this.cidr != null;
    }

    public A withNewCidr(StringBuilder arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(int[] arg1,int arg2,int arg3) {
        return (A)withCidr(new String(arg1, arg2, arg3));
    }

    public A withNewCidr(char[] arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(StringBuffer arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(byte[] arg1,int arg2) {
        return (A)withCidr(new String(arg1, arg2));
    }

    public A withNewCidr(byte[] arg1) {
        return (A)withCidr(new String(arg1));
    }

    public A withNewCidr(char[] arg1,int arg2,int arg3) {
        return (A)withCidr(new String(arg1, arg2, arg3));
    }

    public A withNewCidr(byte[] arg1,int arg2,int arg3) {
        return (A)withCidr(new String(arg1, arg2, arg3));
    }

    public A withNewCidr(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withCidr(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewCidr(String arg1) {
        return (A)withCidr(new String(arg1));
    }

    public Integer getHostPrefix() {
        return this.hostPrefix;
    }

    public A withHostPrefix(Integer hostPrefix) {
        this.hostPrefix=hostPrefix; return (A) this;
    }

    public Boolean hasHostPrefix() {
        return this.hostPrefix != null;
    }

    public A withNewHostPrefix(int arg0) {
        return (A)withHostPrefix(new Integer(arg0));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
        if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
        if (hostPrefix != null ? !hostPrefix.equals(that.hostPrefix) :that.hostPrefix != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(cidr,  hostPrefix,  super.hashCode());
    }

}
